@@ -8,7 +8,7 @@ import logging
 from neurohive.integration.bitbucket import BitBucket
 from neurohive.integration.unitycloud import UnityCloud
 from neurohive.integration.appcenter import AppCenter
-
+from neurohive.deploy.ecs import AwsEcsDeploy
 
 def get_jira_name_from_branch(branch_name):
     regexp = '(feature|bugfix)?(?P<name>\w+-\d+)'
@@ -66,3 +66,12 @@ def cleanup_old_appcenter_build():
     args = parser.parse_args()
     ac = AppCenter(args.owner)
     ac.cleanup_old_builds(args.app_name, args.leave_num)
+
+
+def deploy_ecs_task():
+    parser = argparse.ArgumentParser()
+    parser.add_argument("--def-settings-dir", type=str, required=True)
+    parser.add_argument("--codedeploy-settings", type=str, required=True)
+    args = parser.parse_args()
+    ecs = AwsEcsDeploy(args.def_settings_dir, args.codedeploy_settings)
+    ecs.create_deploy()
