@@ -52,6 +52,8 @@ class LegacyServiceCleaner:
                 if len(action['ForwardConfig']['TargetGroups']) == 1:
                     logging.info("updating last rule weight")
                     action['ForwardConfig']['TargetGroups'][0]['Weight'] = 1
+                else:
+                    action['ForwardConfig']['TargetGroups'][0]['Weight'] = 1
         for condition in rule["Conditions"]:
             if "Values" in condition:
                 del condition["Values"]
@@ -149,15 +151,15 @@ class LegacyServiceCleaner:
         logging.info(f"all vers: {[item['data']['lib_version'] for item in items]}")
         items_vers = {}
         for item in items:
-            version = item['data']['lib_version']
+            version = int(item['data']['lib_version'])
             if not version in items_vers:
                 items_vers[version] = list()
             items_vers[version].append(item)
-        keep_part = sorted(items_vers.keys())[:5]
+        keep_part = sorted(items_vers.keys(), reverse=True)[:5]
         logging.info(f"keep part: {keep_part}")
         delete_items = []
         for item in items:
-            if item['data']['lib_version'] not in keep_part:
+            if int(item['data']['lib_version']) not in keep_part:
                 delete_items.append(item)
         logging.info(f"delete: {[item['data']['lib_version'] for item in delete_items]}")
         return delete_items
